==> jc-1.4.0.tar.gz: gnu/java/nio/NIOConstants.h <==
// public final class gnu.java.nio.NIOConstants

// class file dependencies
// @dep_class 38d4a4183344edde gnu_java_nio_NIOConstants
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_nio_NIOConstants_H_
#define _JC_gnu_java_nio_NIOConstants_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_nio_NIOConstants$sub_refs	_jc_gnu_java_nio_NIOConstants$sub_refs;
typedef struct _jc_gnu_java_nio_NIOConstants$sub_nonrefs	_jc_gnu_java_nio_NIOConstants$sub_nonrefs;
typedef struct _jc_gnu_java_nio_NIOConstants$refs	_jc_gnu_java_nio_NIOConstants$refs;
typedef struct _jc_gnu_java_nio_NIOConstants$nonrefs	_jc_gnu_java_nio_NIOConstants$nonrefs;
typedef struct _jc_gnu_java_nio_NIOConstants$object	_jc_gnu_java_nio_NIOConstants$object;

typedef struct _jc_gnu_java_nio_NIOConstants$fields_struct	_jc_gnu_java_nio_NIOConstants$fields_struct;
typedef const struct _jc_gnu_java_nio_NIOConstants$vmethods	_jc_gnu_java_nio_NIOConstants$vmethods;
typedef const struct _jc_gnu_java_nio_NIOConstants$vtable	_jc_gnu_java_nio_NIOConstants$vtable;
typedef const struct _jc_gnu_java_nio_NIOConstants$vtype	_jc_gnu_java_nio_NIOConstants$vtype;

// Class fields structure
struct _jc_gnu_java_nio_NIOConstants$fields_struct {
	jint	DEFAULT__5fTIMEOUT;
};
extern _jc_gnu_java_nio_NIOConstants$fields_struct _jc_gnu_java_nio_NIOConstants$class_fields;

// Constructors
extern void _jc_gnu_java_nio_NIOConstants$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_nio_NIOConstants$object *);

// Virtual methods structure
struct _jc_gnu_java_nio_NIOConstants$vmethods {
};

// Vtable
struct _jc_gnu_java_nio_NIOConstants$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_nio_NIOConstants$vmethods	gnu_java_nio_NIOConstants;
};

// Vtype
struct _jc_gnu_java_nio_NIOConstants$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_NIOConstants$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_NIOConstants$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_NIOConstants$refs {
    _jc_gnu_java_nio_NIOConstants$sub_refs	gnu_java_nio_NIOConstants;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_NIOConstants$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_NIOConstants$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_nio_NIOConstants$sub_nonrefs	gnu_java_nio_NIOConstants;
};

// Object instance structure
struct _jc_gnu_java_nio_NIOConstants$object {
	_jc_gnu_java_nio_NIOConstants$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_NIOConstants$vtype	*vtype;
	_jc_gnu_java_nio_NIOConstants$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_NIOConstants$vtype _jc_gnu_java_nio_NIOConstants$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_NIOConstants, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_NIOConstants$class_object;

#endif	/* _JC_gnu_java_nio_NIOConstants_H_ */

==> jc-1.4.6.tar.gz: gnu/java/nio/NIOConstants.h <==
// public final class gnu.java.nio.NIOConstants

// class file dependencies
// @dep_class 38d4a4183344edde gnu_java_nio_NIOConstants
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_nio_NIOConstants_H_
#define _JC_gnu_java_nio_NIOConstants_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_nio_NIOConstants$sub_refs	_jc_gnu_java_nio_NIOConstants$sub_refs;
typedef struct _jc_gnu_java_nio_NIOConstants$sub_nonrefs	_jc_gnu_java_nio_NIOConstants$sub_nonrefs;
typedef struct _jc_gnu_java_nio_NIOConstants$refs	_jc_gnu_java_nio_NIOConstants$refs;
typedef struct _jc_gnu_java_nio_NIOConstants$nonrefs	_jc_gnu_java_nio_NIOConstants$nonrefs;
typedef struct _jc_gnu_java_nio_NIOConstants$object	_jc_gnu_java_nio_NIOConstants$object;

typedef struct _jc_gnu_java_nio_NIOConstants$fields_struct	_jc_gnu_java_nio_NIOConstants$fields_struct;
typedef const struct _jc_gnu_java_nio_NIOConstants$vmethods	_jc_gnu_java_nio_NIOConstants$vmethods;
typedef const struct _jc_gnu_java_nio_NIOConstants$vtable	_jc_gnu_java_nio_NIOConstants$vtable;
typedef const struct _jc_gnu_java_nio_NIOConstants$vtype	_jc_gnu_java_nio_NIOConstants$vtype;

// Class fields structure
struct _jc_gnu_java_nio_NIOConstants$fields_struct {
	jint	DEFAULT__5fTIMEOUT;
};
extern _jc_gnu_java_nio_NIOConstants$fields_struct _jc_gnu_java_nio_NIOConstants$class_fields;

// Constructors
extern void _jc_gnu_java_nio_NIOConstants$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_nio_NIOConstants$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_nio_NIOConstants$vmethods {
};

// Vtable
struct _jc_gnu_java_nio_NIOConstants$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_nio_NIOConstants$vmethods	gnu_java_nio_NIOConstants;
};

// Vtype
struct _jc_gnu_java_nio_NIOConstants$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_NIOConstants$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_NIOConstants$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_NIOConstants$refs {
    _jc_gnu_java_nio_NIOConstants$sub_refs	gnu_java_nio_NIOConstants;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_NIOConstants$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_NIOConstants$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_nio_NIOConstants$sub_nonrefs	gnu_java_nio_NIOConstants;
};

// Object instance structure
struct _jc_gnu_java_nio_NIOConstants$object {
	_jc_gnu_java_nio_NIOConstants$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_NIOConstants$vtype	*vtype;
	_jc_gnu_java_nio_NIOConstants$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_NIOConstants$vtype _jc_gnu_java_nio_NIOConstants$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_NIOConstants, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_NIOConstants$class_object;

#endif	/* _JC_gnu_java_nio_NIOConstants_H_ */
